@@ -2,6 +2,7 @@ use crate::common_decl::*;
 use crate::location::{Location, Reg};
 use crate::machine_arm64::MachineARM64;
 use crate::machine_x64::MachineX86_64;
+use crate::unwind::UnwindInstructions;
 use dynasmrt::{AssemblyOffset, DynamicLabel};
 use std::collections::BTreeMap;
 use std::fmt::Debug;
@@ -11,8 +12,7 @@ use wasmer_compiler::{
     Architecture, CallingConvention, CpuFeature, CustomSection, FunctionBody,
     InstructionAddressMap, Relocation, RelocationTarget, Target, TrapInformation,
 };
-use wasmer_types::{FunctionIndex, FunctionType};
-use wasmer_vm::{TrapCode, VMOffsets};
+use wasmer_types::{FunctionIndex, FunctionType, TrapCode, VMOffsets};
 
 pub type Label = DynamicLabel;
 pub type Offset = AssemblyOffset;
@@ -253,8 +253,8 @@ pub trait Machine {
         output: Location<Self::GPR, Self::SIMD>,
     );
 
-    /// emit an Illegal Opcode
-    fn emit_illegal_op(&mut self);
+    /// emit an Illegal Opcode, associated with a trapcode
+    fn emit_illegal_op(&mut self, trp: TrapCode);
     /// create a new label
     fn get_label(&mut self) -> Label;
     /// emit a label
@@ -1038,11 +1038,11 @@ pub trait Machine {
     );
 
     /// emit a move function address to GPR ready for call, using appropriate relocation
-    fn move_with_reloc(
+    fn emit_call_with_reloc(
         &mut self,
+        calling_convention: CallingConvention,
         reloc_target: RelocationTarget,
-        relocations: &mut Vec<Relocation>,
-    );
+    ) -> Vec<Relocation>;
     /// Add with location directly from the stack
     fn emit_binop_add64(
         &mut self,
@@ -2190,6 +2190,10 @@ pub trait Machine {
         sig: &FunctionType,
         calling_convention: CallingConvention,
     ) -> CustomSection;
+    /// generate eh_frame instruction (or None if not possible / supported)
+    fn gen_dwarf_unwind_info(&mut self, code_len: usize) -> Option<UnwindInstructions>;
+    /// generate Windows unwind instructions (or None if not possible / supported)
+    fn gen_windows_unwind_info(&mut self, code_len: usize) -> Option<Vec<u8>>;
 }
 
 /// Standard entry trampoline generation
