@@ -15,8 +15,7 @@
         clippy::float_arithmetic,
         clippy::mut_mut,
         clippy::nonminimal_bool,
-        clippy::option_map_unwrap_or,
-        clippy::option_map_unwrap_or_else,
+        clippy::map_unwrap_or,
         clippy::print_stdout,
         clippy::unicode_not_nfc,
         clippy::use_self
@@ -60,12 +59,18 @@ mod extern_ref;
 mod features;
 mod indexes;
 mod initializers;
+mod libcalls;
+mod memory;
 mod memory_view;
 mod module;
 mod native;
+mod table;
+mod trapcode;
 mod types;
 mod units;
+mod utils;
 mod values;
+mod vmoffsets;
 
 /// The entity module, with common helpers for Rust structures
 pub mod entity;
@@ -94,5 +99,13 @@ pub use types::{
 #[cfg(feature = "enable-rkyv")]
 pub use archives::ArchivableIndexMap;
 
+pub use crate::libcalls::LibCall;
+pub use crate::memory::MemoryStyle;
+pub use crate::table::TableStyle;
+pub use crate::trapcode::TrapCode;
+pub use crate::vmoffsets::{TargetSharedSignatureIndex, VMBuiltinFunctionIndex, VMOffsets};
+
+pub use crate::utils::is_wasm;
+
 /// Version number of this crate.
 pub const VERSION: &str = env!("CARGO_PKG_VERSION");
